/**
   @author Shin'ichiro Nakaoka
*/

#include "Plugin.h"
#include "Item.h"
#include "ToolBar.h"
#include "View.h"
#include <boost/variant.hpp>

using namespace std;
using namespace boost;
using namespace cnoid;


namespace cnoid {

    class PluginImpl
    {
    public:
        PluginImpl(const char* name);

        string name;
        vector<string> dependencies;
        vector<string> oldNames;
    };
}


Plugin::Plugin(const char* name)
    : ExtensionManager(name)
{
    impl = new PluginImpl(name);
}


PluginImpl::PluginImpl(const char* name)
    : name(name)
{

}


Plugin::~Plugin() 
{
    delete impl;
}


const char* Plugin::name()
{
    return impl->name.c_str();
}


bool Plugin::initialize()
{
    return true;
}


bool Plugin::finalize()
{
    return true;
}


void Plugin::depend(const char* pluginName)
{
    impl->dependencies.push_back(pluginName);
}


const char* Plugin::dependency(int index)
{
    return impl->dependencies[index].c_str();
}


int Plugin::numDependencies()
{
    return impl->dependencies.size();
}


void Plugin::rememberOldName(const char* name)
{
    impl->oldNames.push_back(name);
}


const char* Plugin::oldName(int index)
{
    return impl->oldNames[index].c_str();
}


int Plugin::numOldNames()
{
    return impl->oldNames.size();
}


QString Plugin::description()
{
    return QString();
}


QString Plugin::LGPLtext()
{
    return
        tr("This program is free software; you can redistribute it and/or modify it under the terms of "
           "the GNU Lesser General Public License as published by the Free Software Foundation; either "
           "version 2.1 of the License, or (at your option) any later version.\n"
           "\n"
           "This package is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; "
           "without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
           "See the GNU Lesser General Public License for more details.\n");
}



